@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 4931 2012-06-03 12:38:04Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 5127 2012-08-21 10:11:14Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -102,7 +102,7 @@ class BaseFrameContainer extends Core
 					// アクセス可能な言語な場合は変更
 					if (in_array($lang, $this->gSystem->getAcceptLanguage())){
 						$this->gEnv->setCurrentLanguage($lang);
-					
+						
 						// クッキーに言語を保存
 						$request->setCookieValue(M3_COOKIE_LANG, $lang);
 					} else {		// アクセス不可の場合はクッキーを削除
@@ -113,6 +113,8 @@ class BaseFrameContainer extends Core
 					// クッキーを削除
 					$request->setCookieValue(M3_COOKIE_LANG, '', -1);
 				}
+				// 言語に依存する情報を取り込む
+				$this->gPage->loadLang();
 			}
 			// ################### URLアクセス制御 ######################
 			// 非公開URLへは管理権限がないとアクセスできない
