@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 5008 2012-07-03 05:36:34Z fishbone $
+ * @version    SVN: $Id: envManager.php 5114 2012-08-16 01:04:11Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -90,6 +90,7 @@ class EnvManager extends Core
 	const CF_USE_SSL_ADMIN = 'use_ssl_admin';		// 管理画面にSSL機能を使用するかどうか
 	const CF_SSL_URL = 'ssl_root_url';				// SSL用のルートURL
 	const CF_DEFAULT_LANG = 'default_lang';			// デフォルト言語
+	const DEFAULT_SITE_NAME = 'サイト名未設定';		// 管理画面用のデフォルトサイト名
 	
 	/**
 	 * コンストラクタ
@@ -1985,11 +1986,12 @@ class EnvManager extends Core
 	 */
 	public function getSiteName($reload = false)
 	{
-		// DBが使用不可のときは空文字列を返す
-		if (!$this->canUseDb) return '';
+		// DBが使用不可のときはデフォルト名を返す
+		if (!$this->canUseDb) return self::DEFAULT_SITE_NAME;
 		
 		if ($reload || empty($this->siteName)){			// サイト名称
 			$this->siteName = $this->gSystem->getSiteDef(M3_TB_FIELD_SITE_NAME);
+			if (empty($this->siteName)) $this->siteName = self::DEFAULT_SITE_NAME;
 		}
 		return $this->siteName;
 	}
