@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 5072 2012-07-31 03:54:46Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 5118 2012-08-18 09:01:17Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('default_content') . '/admin_default_contentBaseWidgetContainer.php');
@@ -22,9 +22,11 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 	private $serialArray = array();		// 表示されているコンテンツシリアル番号
 	private $selectedItem = array();	// 選択中の項目
 	private $attachFileInfoArray;		// 添付ファイルの情報
+	private $fieldValueArray;		// ユーザ定義フィールド入力値
 	private $completed;			// データ登録完了かどうか
 	private $isExistsContent;		// コンテンツ項目が存在するかどうか
 	private $isMultiLang;			// 多言語対応画面かどうか
+	private $isOpenOptionArea;		// 拡張エリアを開くかどうか
 	const ICON_SIZE = 16;		// アイコンのサイズ
 	const PANEL_BUTTON_SIZE = 32;	// 拡張エリア制御ボタンサイズ
 	const INC_INDEX = 1;		// メニュー項目表示順の増加分
@@ -45,6 +47,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 	const LOG_MSG_ADD_CONTENT = '汎用コンテンツ(%s)を追加しました。タイトル: %s';
 	const LOG_MSG_UPDATE_CONTENT = '汎用コンテンツ(%s)を更新しました。タイトル: %s';
 	const LOG_MSG_DEL_CONTENT = '汎用コンテンツ(%s)を削除しました。タイトル: %s';
+	const FIELD_HEAD = 'item_';			// フィールド名の先頭文字列
 	
 	/**
 	 * コンストラクタ
@@ -273,11 +276,17 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			$langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
 			if (!empty($langId)) $this->langId = $langId;
 		}
+		// コンテンツレイアウトを取得
+		$contentLayout = self::$_configArray[default_contentCommonDef::$CF_LAYOUT_VIEW_DETAIL];
+		$fieldInfoArray = default_contentCommonDef::parseUserMacro($contentLayout);
+
+		// 入力値を取得
 		$act = $request->trimValueOf('act');
 		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
 		$contentId = $request->trimValueOf('contentid');		// コンテンツID
 		$name = $request->trimValueOf('item_name');
 		$html = $request->valueOf('item_html');		// HTMLタグを可能とする
+		$desc = $request->trimValueOf('item_desc');		// 簡易説明
 		$key = $request->trimValueOf('item_key');		// 外部参照用キー
 		$visible = ($request->trimValueOf('item_visible') == 'on') ? 1 : 0;		// チェックボックス
 		$limited = ($request->trimValueOf('item_limited') == 'on') ? 1 : 0;		// チェックボックス
@@ -308,6 +317,16 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		}
 		if (!empty($end_time)) $end_time = $this->convertToProperTime($end_time, 1/*時分フォーマット*/);
 		
+		// ユーザ定義フィールド入力値取得
+		$this->fieldValueArray = array();		// ユーザ定義フィールド入力値
+		$fieldKeys = array_keys($fieldInfoArray);
+		for ($i = 0; $i < count($fieldKeys); $i++){
+			$fieldKey = $fieldKeys[$i];
+			$itemName = self::FIELD_HEAD . $fieldKey;
+			$itemValue = $this->cleanMacroValue($request->trimValueOf($itemName));
+			if (!empty($itemValue)) $this->fieldValueArray[$fieldKey] = $itemValue;
+		}
+		
 		// 添付ファイルリスト取得
 		$attachFileCount = $request->trimValueOf('attachfilecount');		// 添付ファイル数
 		$fileTitles	= $request->trimValueOf('item_filetitle');		// 添付ファイルタイトル
@@ -321,11 +340,11 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			$newInfoObj->fileId		= $fileIds[$i];
 			$this->attachFileInfoArray[] = $newInfoObj;
 		}
-		
+
 		$reloadData = false;		// データの再読み込み
 		$hasPassword = false;		// パスワードが設定されているかどうか
 		$histryIndex = -1;	// 履歴番号
-		if ($act == 'add'){		// 項目追加の場合
+		if ($act == 'add'){		// 項目追加の場合。多言語対応の場合はデフォルト言語が最初に追加される。
 			// 入力チェック
 			$this->checkInput($name, '名前');
 
@@ -347,15 +366,32 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				} else {
 					$endDt = $end_date . ' ' . $end_time;
 				}
+
+				// サムネール画像を取得
+				$thumbFilename = '';
+				if (($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang){		// // 多言語対応の場合はデフォルト言語が選択されている場合のみ処理を行う
+					// 次のコンテンツIDを取得
+					$nextContentId = self::$_mainDb->getNextContentId(default_contentCommonDef::$_contentType);
+				
+					$thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html);
+					if (!empty($thumbPath)){
+						$ret = $this->gInstance->getImageManager()->createSystemDefaultThumb(M3_VIEW_TYPE_CONTENT, default_contentCommonDef::$_deviceType, $nextContentId, $thumbPath, $destFilename);
+						if ($ret) $thumbFilename = implode(';', $destFilename);
+					}
+				}
 				
 				// 追加パラメータ
-				$otherParams = array('cn_related_content' => $relatedContent);		// 関連コンテンツ
+				$otherParams = array(	'cn_thumb_filename'		=> $thumbFilename,		// サムネールファイル名
+										'cn_related_content'	=> $relatedContent,		// 関連コンテンツ
+										'cn_option_fields'		=> $this->serializeArray($this->fieldValueArray));				// ユーザ定義フィールド値
 				
-				if ($this->isMultiLang){		// 多言語対応の場合
-					$ret = self::$_mainDb->addContentItem(default_contentCommonDef::$_contentType, $contentId, $this->langId, $name, ''/*説明*/, $html, $visible, $default, $limited, $key, $password, 
+				if (($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang){		// 多言語でデフォルト言語、または単一言語のとき
+					$ret = self::$_mainDb->addContentItem(default_contentCommonDef::$_contentType, $nextContentId * (-1)/*次のコンテンツIDのチェック*/,
+														$this->langId, $name, $desc, $html, $visible, $default, $limited, $key, $password, 
 														$metaTitle, $metaDesc, $metaKeyword, $startDt, $endDt, $newSerial, $otherParams);
 				} else {
-					$ret = self::$_mainDb->addContentItem(default_contentCommonDef::$_contentType, 0, $this->langId, $name, ''/*説明*/, $html, $visible, $default, $limited, $key, $password, 
+					$ret = self::$_mainDb->addContentItem(default_contentCommonDef::$_contentType, $contentId, 
+														$this->langId, $name, $desc, $html, $visible, $default, $limited, $key, $password, 
 														$metaTitle, $metaDesc, $metaKeyword, $startDt, $endDt, $newSerial, $otherParams);
 				}
 				// ##### 添付ファイル情報を更新 #####
@@ -420,13 +456,31 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					$endDt = $end_date . ' ' . $end_time;
 				}
 				
+				// サムネール画像を取得
+				$thumbFilename = '';
+				if (($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang){		// // 多言語対応の場合はデフォルト言語が選択されている場合のみ処理を行う
+					$thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html);
+					if (!empty($thumbPath)){
+						$ret = $this->gInstance->getImageManager()->createSystemDefaultThumb(M3_VIEW_TYPE_CONTENT, default_contentCommonDef::$_deviceType, $contentId, $thumbPath, $destFilename);
+						if ($ret) $thumbFilename = implode(';', $destFilename);
+					}
+				}
+
 				// 追加パラメータ
-				$otherParams = array('cn_related_content' => $relatedContent);		// 関連コンテンツ
-				
-				$ret = self::$_mainDb->updateContentItem($this->serialNo, $name, $html, $visible, $default, $limited, $key, $password, 
-															$metaTitle, $metaDesc, $metaKeyword, $startDt, $endDt, $newSerial, $otherParams);
-				// ##### 添付ファイル情報を更新 #####
+				$otherParams = array(	'cn_thumb_filename'		=> $thumbFilename,		// サムネールファイル名
+										'cn_related_content'	=> $relatedContent,		// 関連コンテンツ
+										'cn_option_fields'		=> $this->serializeArray($this->fieldValueArray));				// ユーザ定義フィールド値
+										
+				$ret = self::$_mainDb->updateContentItem($this->serialNo, $name, $desc, $html, $visible, $default, $limited, $key, $password, 
+															$metaTitle, $metaDesc, $metaKeyword, $startDt, $endDt, $newSerial, $oldRecord, $otherParams);
 				if ($ret){
+					// コンテンツに画像がなくなった場合は、サムネールを削除
+					if (empty($thumbFilename) && !empty($oldRecord['cn_thumb_filename'])){
+						$oldFiles = explode(';', $oldRecord['cn_thumb_filename']);
+						$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_CONTENT, default_contentCommonDef::$_deviceType, $oldFiles);
+					}
+				
+					// ##### 添付ファイル情報を更新 #####
 					$ret = self::$_mainDb->getContentBySerial($newSerial, $row);
 					if ($ret){
 						$contentId = $row['cn_id'];		// コンテンツID
@@ -492,13 +546,20 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					// 多言語対応状態に関わらずコンテンツIDで削除
 					$ret = self::$_mainDb->delContentItemById(array($this->serialNo));
 				}
-				
-				// ##### 添付ファイルを削除 #####
+			
 				if ($ret){
 					if ($delByContentId){		// コンテンツIDで削除のとき
+						// サムネールを削除
+						if (!empty($row['cn_thumb_filename'])){
+							$oldFiles = explode(';', $row['cn_thumb_filename']);
+							$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_CONTENT, default_contentCommonDef::$_deviceType, $oldFiles);
+						}
+						
+						// 添付ファイルを削除
 						$ret = $this->gInstance->getFileManager()->delAttachFileInfoByContentId(default_contentCommonDef::$_viewContentType,
 																								$contentId, default_contentCommonDef::getAttachFileDir());
 					} else {
+						// 添付ファイルを削除
 						$ret = $this->gInstance->getFileManager()->delAttachFileInfo(default_contentCommonDef::$_viewContentType,
 																						$this->serialNo, default_contentCommonDef::getAttachFileDir());
 					}
@@ -599,6 +660,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				$contentId = $row['cn_id'];		// コンテンツID
 				$name = $row['cn_name'];		// コンテンツ名前
 				$html = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->getUrl($this->gEnv->getRootUrl()), $row['cn_html']);				// HTML
+				$desc = $row['cn_description'];		// 簡易説明
 				$key = $row['cn_key'];					// 外部参照用キー
 				$update_user = $this->convertToDispString($row['lu_name']);// 更新者
 				$update_dt = $this->convertToDispDateTime($row['cn_create_dt']);
@@ -622,6 +684,9 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				// 履歴番号
 				if ($row['cn_deleted']) $histryIndex = $row['cn_history_index'];
 				
+				// ユーザ定義フィールド
+				$this->fieldValueArray = $this->unserializeArray($row['cn_option_fields']);
+
 				// ##### 添付ファイル情報を取得 #####
 				// 多言語対応の場合はデフォルト言語が選択されている場合のみ処理を行う
 				if (($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang){
@@ -638,6 +703,9 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 						}
 					}
 				}
+				
+				// 拡張エリアの状態を設定
+				if ($hasPassword || !empty($key) || !empty($relatedContent) || count($this->attachFileInfoArray) > 0) $this->isOpenOptionArea = true;
 			} else {
 				$this->serialNo = 0;
 			}
@@ -671,6 +739,8 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			$this->tmpl->setAttribute('show_singlelang', 'visibility', 'visible');
 			$this->tmpl->addVar("show_singlelang", "sel_item_name", $name);		// 名前
 		}
+		// ユーザ定義フィールドを作成
+		$this->createUserFields($fieldInfoArray);
 		
 		// 添付ファイル一覧作成
 		$this->createAttachFileList();
@@ -686,6 +756,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		
 		// ### 入力値を再設定 ###
 		$this->tmpl->addVar("_widget", "sel_item_html", $html);		// HTML
+		$this->tmpl->addVar("_widget", "desc", $desc);		// 簡易説明
 		$this->tmpl->addVar("_widget", "sel_item_key", $key);		// 外部参照用キー
 		$this->tmpl->addVar("_widget", "meta_title", $metaTitle);		// ページタイトル名(METAタグ)
 		$this->tmpl->addVar("_widget", "meta_desc", $metaDesc);		// ページ要約(METAタグ)
@@ -739,7 +810,12 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		$this->tmpl->addVar('_widget', 'admin_widget_id', self::ADMIN_WIDGET_ID);// ユーザ定義値参照用(管理ウィジェットのウィジェットID)
 		$this->tmpl->addVar('_widget', 'calendar_img', $this->getUrl($this->gEnv->getRootUrl() . self::CALENDAR_ICON_FILE));	// カレンダーアイコン
 		
-		// 拡張エリア制御ボタン
+		// 拡張エリア制御
+		if ($this->isOpenOptionArea){
+			$this->tmpl->addVar('_widget', 'option_area_open', 'true');
+		} else {
+			$this->tmpl->addVar('_widget', 'option_area_open', 'false');
+		}
 		$iconUrl = $this->gEnv->getRootUrl() . self::OPEN_PANEL_ICON_FILE;		// 拡張エリア表示用アイコン
 		$iconTitle = 'オプション表示';
 		$openButton = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::PANEL_BUTTON_SIZE . '" height="' . self::PANEL_BUTTON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
@@ -1146,5 +1222,36 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			$this->tmpl->parseTemplate('attach_file_list', 'a');
 		}
 	}
+	/**
+	 * ユーザ定義フィールドを作成
+	 *
+	 * @param array $fields			フィールドID
+	 * @return bool					true=成功、false=失敗
+	 */
+	function createUserFields($fields)
+	{
+		if (count($fields) == 0) return true;
+		
+		$this->tmpl->setAttribute('user_fields', 'visibility', 'visible');
+		$keys = array_keys($fields);
+		$fieldCount = count($keys);
+		for ($i = 0; $i < $fieldCount; $i++){
+			if ($i == 0) $this->tmpl->addVar('user_fields', 'type', 'first');		// 最初の行の場合
+			
+			// 入力値を取得
+			$key = $keys[$i];
+			$value = $this->fieldValueArray[$key];
+			if (!isset($value)) $value = '';
+			
+			$row = array(
+				'row_count'	=> $fieldCount,
+				'field_id'	=> $this->convertToDispString($key),
+				'value'		=> $this->convertToDispString($value)
+			);
+			$this->tmpl->addVars('user_fields', $row);
+			$this->tmpl->parseTemplate('user_fields', 'a');
+		}
+		return true;
+	}
 }
 ?>
