@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentCommonDef.php 5047 2012-07-20 09:58:03Z fishbone $
+ * @version    SVN: $Id: default_contentCommonDef.php 5102 2012-08-11 07:54:51Z fishbone $
  * @link       http://www.magic3.org
  */
  
@@ -25,11 +25,14 @@ class default_contentCommonDef
 	static $CF_USE_PASSWORD			= 'use_password';		// パスワードアクセス制御
 	static $CF_PASSWORD_CONTENT		= 'password_content';			// パスワード画面コンテンツ
 	static $CF_LAYOUT_VIEW_DETAIL	= 'layout_view_detail';			// コンテンツレイアウト(詳細表示)
+	static $CF_OUTPUT_HEAD			= 'output_head';		// ヘッダ出力するかどうか
+	static $CF_HEAD_VIEW_DETAIL		= 'head_view_detail';			// ヘッダ出力(詳細表示)
 	
 	const CONTENT_WIDGET_ID = 'default_content';		// デフォルトの汎用コンテンツ編集ウィジェット
 	const ATTACH_FILE_DIR = '/etc/content';				// 添付ファイル格納ディレクトリ
 	const DOWNLOAD_CONTENT_TYPE = '-file';				// ダウンロードするコンテンツのタイプ
 	const DEFAULT_CONTENT_LAYOUT = '[#BODY#][#FILES#][#PAGES#][#LINKS#]';	// デフォルトのコンテンツレイアウト
+	const DEFAULT_HEAD_VIEW_DETAIL = '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />';	// デフォルトのヘッダ出力(詳細表示)
 	
 	/**
 	 * フォトギャラリー定義値をDBから取得
@@ -66,5 +69,23 @@ class default_contentCommonDef
 		if (!file_exists($dir)) mkdir($dir, M3_SYSTEM_DIR_PERMISSION, true/*再帰的*/);
 		return $dir;
 	}
+	/**
+	 * レイアウトからユーザ定義フィールドを取得
+	 *
+	 * @param string $src			変換するデータ
+	 * @return array				フィールドID
+	 */
+	static function parseUserMacro($src)
+	{
+		$fields = array();
+		$pattern = '/' . preg_quote(M3_TAG_START . M3_TAG_MACRO_USER_KEY) . '([A-Z0-9_]+):?(.*?)' . preg_quote(M3_TAG_END) . '/u';
+		preg_match_all($pattern, $src, $matches, PREG_SET_ORDER);
+		for ($i = 0; $i < count($matches); $i++){
+			$key = M3_TAG_MACRO_USER_KEY . $matches[$i][1];
+			$value = $matches[$i][2];
+			if (!array_key_exists($key, $fields)) $fields[$key] = $value;
+		}
+		return $fields;
+	}
 }
 ?>
