@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 5069 2012-07-30 10:34:34Z fishbone $
+ * @version    SVN: $Id: index.php 5102 2012-08-11 07:54:51Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -50,6 +50,8 @@ $HELP['content_act']['title'] = '操作';
 $HELP['content_act']['body'] = '各種操作を行います。<br />●メニューに追加<br />メニュー定義にコンテンツを表示するメニュー項目を追加します。<br />●プレビュー<br />コンテンツをプレビュー表示します。';
 $HELP['content_html']['title'] = 'HTML';
 $HELP['content_html']['body'] = 'コンテンツの内容となるHTMLです。';
+$HELP['content_desc']['title'] = '簡易説明';
+$HELP['content_desc']['body'] = 'コンテンツの概要を設定します。';
 $HELP['content_ref_custom']['title'] = '置換文字列を参照';
 $HELP['content_ref_custom']['body'] = 'コンテンツに埋め込んだ置換文字列はコンテンツ表示時に設定文字列に変換します。置換文字列の設定値を参照します。';
 $HELP['content_key']['title'] = '外部参照用キー';
